colour_hdri.recovery Package — Colour - HDRI 0.1.0 documentation

# colour_hdri.recovery Package

## Sub-Modules

- colour_hdri.recovery.highlights Module
  - Clipped Highlights Recovery

## Module Contents

`colour_hdri.recovery.` `highlights_recovery_blend`(RGB, multipliers, threshold=0.99)

  Performs highlights recovery using Coffin (1997) method from dcraw.

  Parameters: | RGB (array_like) – RGB colourspace array. multipliers (array_like) – Normalised camera white level or white balance multipliers. threshold (numeric, optional) – Threshold for the highlights selection.
  Returns: | Highlights recovered RGB colourspace array.
  Return type: | ndarray

  References

  [1] | Coffin, D. (2015). dcraw. Retrieved from https://www.cybercom.net/~dcoffin/dcraw/